@@ -28,6 +28,10 @@ class BridgeBusy(AiohueException):
     """Raised when multiple requests to the bridge failed."""
 
 
+class BridgeSoftwareOutdated(AiohueException):
+    """Raised when the software version of the bridge is (too) outdated."""
+
+
 ERRORS = {1: Unauthorized, 101: LinkButtonNotPressed}
 
 
