@@ -2,6 +2,8 @@
 import asyncio
 from typing import TYPE_CHECKING, Dict, Optional, Type, Union
 
+from aiohue.util import dataclass_to_dict
+
 from ..models.button import Button, ButtonEvent
 from ..models.device_power import DevicePower
 from ..models.geofence_client import GeofenceClient
@@ -34,6 +36,7 @@ class DevicePowerController(BaseResourcesController[Type[DevicePower]]):
 
     item_type = ResourceTypes.DEVICE_POWER
     item_cls = DevicePower
+    allow_parser_error = True
 
 
 class ButtonController(BaseResourcesController[Type[Button]]):
@@ -41,6 +44,7 @@ class ButtonController(BaseResourcesController[Type[Button]]):
 
     item_type = ResourceTypes.BUTTON
     item_cls = Button
+    allow_parser_error = True
 
     _workaround_tasks: Dict[str, asyncio.Task] = None
 
@@ -48,7 +52,7 @@ class ButtonController(BaseResourcesController[Type[Button]]):
         self, evt_type: EventType, evt_data: Optional[dict], skip_forward: bool = False
     ) -> None:
         """Handle incoming event for this resource from the EventStream."""
-        await super()._handle_event(type, evt_data)
+        await super()._handle_event(evt_type, evt_data)
 
         # Handle longpress workaround if needed
         if (
@@ -82,16 +86,16 @@ class ButtonController(BaseResourcesController[Type[Button]]):
         # Fake `held down` and `long press release` events.
         # This might need to be removed in a future release once/if Signify
         # adds this back in their API.
+        btn_resource = dataclass_to_dict(self._items[id])
         await asyncio.sleep(1.5)  # time to initially wait for SHORT_RELEASE
         count = 0
         try:
             while count <= 20:  # = max 10 seconds
-                btn_resource = self._items[id]
-                cur_event = btn_resource.button.last_event
+                cur_event = self._items[id].button.last_event
                 if cur_event == ButtonEvent.SHORT_RELEASE:
                     break
                 # send REPEAT until short release is received
-                btn_resource.button.last_event = ButtonEvent.REPEAT
+                btn_resource["button"]["last_event"] = ButtonEvent.REPEAT.value
                 await self._handle_event(EventType.RESOURCE_UPDATED, btn_resource)
                 await asyncio.sleep(0.5)
                 count += 1
@@ -102,8 +106,7 @@ class ButtonController(BaseResourcesController[Type[Button]]):
             # Note that the button will also fire the SHORT_RELEASE event if it's released within
             # those 10 seconds.
             if count > 1:
-                btn_resource = self._items[id]
-                btn_resource.button.last_event = ButtonEvent.LONG_RELEASE
+                btn_resource["button"]["last_event"] = ButtonEvent.LONG_RELEASE.value
                 await self._handle_event(EventType.RESOURCE_UPDATED, btn_resource)
 
 
@@ -112,6 +115,7 @@ class GeofenceClientController(BaseResourcesController[Type[GeofenceClient]]):
 
     item_type = ResourceTypes.GEOFENCE_CLIENT
     item_cls = GeofenceClient
+    allow_parser_error = True
 
 
 class LightLevelController(BaseResourcesController[Type[LightLevel]]):
@@ -119,6 +123,7 @@ class LightLevelController(BaseResourcesController[Type[LightLevel]]):
 
     item_type = ResourceTypes.LIGHT_LEVEL
     item_cls = LightLevel
+    allow_parser_error = True
 
     async def set_enabled(self, id: str, enabled: bool) -> None:
         """Enable/Disable sensor."""
@@ -130,6 +135,7 @@ class MotionController(BaseResourcesController[Type[Motion]]):
 
     item_type = ResourceTypes.MOTION
     item_cls = Motion
+    allow_parser_error = True
 
     async def set_enabled(self, id: str, enabled: bool) -> None:
         """Enable/Disable sensor."""
@@ -141,6 +147,7 @@ class TemperatureController(BaseResourcesController[Type[Temperature]]):
 
     item_type = ResourceTypes.TEMPERATURE
     item_cls = Temperature
+    allow_parser_error = True
 
 
 class ZigbeeConnectivityController(BaseResourcesController[Type[ZigbeeConnectivity]]):
@@ -148,6 +155,7 @@ class ZigbeeConnectivityController(BaseResourcesController[Type[ZigbeeConnectivi
 
     item_type = ResourceTypes.ZIGBEE_CONNECTIVITY
     item_cls = ZigbeeConnectivity
+    allow_parser_error = True
 
 
 class SensorsController(GroupedControllerBase[SENSOR_TYPES]):
